Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(26)

Unified Diff: chrome/browser/content_settings/host_content_settings_map.cc

Issue 369703002: Remember user decisions on invalid certificates behind a flag (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixed broken include Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/content_settings/host_content_settings_map.cc
diff --git a/chrome/browser/content_settings/host_content_settings_map.cc b/chrome/browser/content_settings/host_content_settings_map.cc
index e8088217975b5dcfc6b58c449858284bd79adf59..da348b050eacc334d0eefeb3974c2c07ed50b35f 100644
--- a/chrome/browser/content_settings/host_content_settings_map.cc
+++ b/chrome/browser/content_settings/host_content_settings_map.cc
@@ -477,16 +477,19 @@ bool HostContentSettingsMap::IsSettingAllowedForType(
// static
bool HostContentSettingsMap::ContentTypeHasCompoundValue(
ContentSettingsType type) {
// Values for content type CONTENT_SETTINGS_TYPE_AUTO_SELECT_CERTIFICATE and
// CONTENT_SETTINGS_TYPE_MEDIASTREAM are of type dictionary/map. Compound
// types like dictionaries can't be mapped to the type |ContentSetting|.
#if defined(OS_ANDROID)
if (type == CONTENT_SETTINGS_TYPE_APP_BANNER)
return true;
#endif
return (type == CONTENT_SETTINGS_TYPE_AUTO_SELECT_CERTIFICATE ||
- type == CONTENT_SETTINGS_TYPE_MEDIASTREAM);
+ type == CONTENT_SETTINGS_TYPE_MEDIASTREAM ||
+ type == CONTENT_SETTINGS_TYPE_SSL_CERT_DECISIONS);
}
void HostContentSettingsMap::OnContentSettingChanged(
@@ -477,16 +477,19 @@ bool HostContentSettingsMap::IsSettingAllowedForType(
bool HostContentSettingsMap::ContentTypeHasCompoundValue(
ContentSettingsType type) {
- // Values for content type CONTENT_SETTINGS_TYPE_AUTO_SELECT_CERTIFICATE and
- // CONTENT_SETTINGS_TYPE_MEDIASTREAM are of type dictionary/map. Compound
- // types like dictionaries can't be mapped to the type |ContentSetting|.
+ // Values for content type CONTENT_SETTINGS_TYPE_AUTO_SELECT_CERTIFICATE,
+ // CONTENT_SETTINGS_TYPE_MEDIASTREAM, and
+ // CONTENT_SETTINGS_TYPE_SSL_CERT_DECISIONS are of type dictionary/map.
+ // Compound types like dictionaries can't be mapped to the type
+ // |ContentSetting|.
#if defined(OS_ANDROID)
if (type == CONTENT_SETTINGS_TYPE_APP_BANNER)

Powered by Google App Engine
This is Rietveld 408576698